Exception: YANAPI::EmptyResponse
- Defined in:
- lib/yanapi/error.rb
Overview
This kind of error is used, if there is no answer to our request. The status code is 200 OK and the xml structure is valid, but there is no useful information in the response. We can check this way if we have just placed a too strict request or we are out of the response range (but we are under the :start limitations).